@@ -1,7 +1,7 @@
 //! Types for sending data to and from the language client.
 
 use std::fmt::{self, Debug, Display, Formatter};
-use std::sync::atomic::{AtomicU64, Ordering};
+use std::sync::atomic::{AtomicU32, Ordering};
 use std::sync::Arc;
 
 use futures::channel::mpsc::Sender;
@@ -18,7 +18,7 @@ use super::{ServerState, State};
 
 struct ClientInner {
     sender: Sender<Outgoing>,
-    request_id: AtomicU64,
+    request_id: AtomicU32,
     pending_requests: Arc<ClientRequests>,
     state: Arc<ServerState>,
 }
@@ -43,7 +43,7 @@ impl Client {
         Client {
             inner: Arc::new(ClientInner {
                 sender,
-                request_id: AtomicU64::new(0),
+                request_id: AtomicU32::new(0),
                 pending_requests,
                 state,
             }),
@@ -295,7 +295,7 @@ impl Client {
     ///
     /// This request was introduced in specification version 3.16.0.
     pub async fn semantic_tokens_refresh(&self) -> Result<()> {
-        self.send_request_initialized::<SemanticTokensRefesh>(())
+        self.send_request_initialized::<SemanticTokensRefresh>(())
             .await
     }
 
@@ -356,7 +356,7 @@ impl Client {
         let id = self.inner.request_id.fetch_add(1, Ordering::Relaxed);
         let message = Outgoing::Request(ClientRequest::request::<R>(id, params));
 
-        let response_waiter = self.inner.pending_requests.wait(Id::Number(id));
+        let response_waiter = self.inner.pending_requests.wait(Id::Number(id as i64));
 
         if self.inner.sender.clone().send(message).await.is_err() {
             error!("failed to send request");
@@ -426,9 +426,9 @@ mod tests {
         assert_eq!(messages, vec![Outgoing::Request(expected)]);
     }
 
-    #[tokio::test]
+    #[tokio::test(flavor = "current_thread")]
     async fn log_message() {
-        let (typ, msg) = (MessageType::Log, "foo bar".to_owned());
+        let (typ, msg) = (MessageType::LOG, "foo bar".to_owned());
         let expected = ClientRequest::notification::<LogMessage>(LogMessageParams {
             typ,
             message: msg.clone(),
@@ -437,9 +437,9 @@ mod tests {
         assert_client_messages(|p| async move { p.log_message(typ, msg).await }, expected).await;
     }
 
-    #[tokio::test]
+    #[tokio::test(flavor = "current_thread")]
     async fn show_message() {
-        let (typ, msg) = (MessageType::Log, "foo bar".to_owned());
+        let (typ, msg) = (MessageType::LOG, "foo bar".to_owned());
         let expected = ClientRequest::notification::<ShowMessage>(ShowMessageParams {
             typ,
             message: msg.clone(),
@@ -448,7 +448,7 @@ mod tests {
         assert_client_messages(|p| async move { p.show_message(typ, msg).await }, expected).await;
     }
 
-    #[tokio::test]
+    #[tokio::test(flavor = "current_thread")]
     async fn telemetry_event() {
         let null = json!(null);
         let expected = ClientRequest::notification::<TelemetryEvent>(null.clone());
@@ -468,7 +468,7 @@ mod tests {
         assert_client_messages(|p| async move { p.telemetry_event(other).await }, expected).await;
     }
 
-    #[tokio::test]
+    #[tokio::test(flavor = "current_thread")]
     async fn publish_diagnostics() {
         let uri: Url = "file:///path/to/file".parse().unwrap();
         let diagnostics = vec![Diagnostic::new_simple(Default::default(), "example".into())];
